@@ -1,11 +1,10 @@
-
-# bayes factor (independent samples t-test) ----------------------
-
 test_that(
   desc = "bayes factor (independent samples t-test)",
   code = {
     skip_if(getRversion() < "4.0")
 
+    # bayes factor (independent samples t-test) ----------------------
+
     # from Bayes Factor
     df <- suppressMessages(bf_extractor(
       BayesFactor::ttestBF(
@@ -34,26 +33,15 @@ test_that(
       )
 
     # call
-    expect_identical(
-      bf_expr$expression[[1]],
-      ggplot2::expr(
-        paste("log"["e"] * "(BF"["01"] * ") = " *
-          "-0.18" * ", ", widehat(italic(delta))["difference"]^"posterior" *
-          " = " * "-3.16" * ", ", "CI"["99%"]^"HDI" *
-          " [" * "-8.13" * ", " * "1.35" *
-          "], ", italic("r")["Cauchy"]^"JZS" *
-          " = " * "0.71")
-      )
-    )
+    expect_snapshot(bf_expr$expression[[1]])
   }
 )
 
-# Bayes factor (paired t-test) ---------------------------------------------
-
 test_that(
   desc = "bayes factor (paired t-test)",
   code = {
 
+    # Bayes factor (paired t-test) ---------------------------------------------
 
     # data
     dat <-
@@ -92,29 +80,15 @@ test_that(
       )
 
     # call
-    expect_identical(
-      bf_expr$expression[[1]],
-      ggplot2::expr(
-        atop(displaystyle("bla"),
-          expr = paste(
-            "log"["e"] *
-              "(BF"["01"] * ") = " * "-3.70" * ", ",
-            widehat(italic(delta))["difference"]^"posterior" * " = " * "-1.09" * ", ",
-            "CI"["95%"]^"HDI" * " [" * "-1.70" * ", " * "-0.49" * "], ",
-            italic("r")["Cauchy"]^"JZS" * " = " * "0.80"
-          )
-        )
-      )
-    )
+    expect_snapshot(bf_expr$expression[[1]])
   }
 )
 
-# works with subject id ------------------------------------------------------
-
 test_that(
   desc = "works with subject id",
   code = {
 
+    # works with subject id -----------------------------------------------
 
     # data
     df <-
